/***************************************************************************
 *   copyright            : (C) 1999 by Daniel Reith                       *
 *   email                : DanR@gmx.de                                    *
 *                                                                         *
 *   copyright           : (C) 2003 by Hendrik Sattler                     *
 *   mail                : pingos@hendrik-sattler.de                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KURSLAUS_H
#define KURSLAUS_H

#include "kurs.h"
#include "lektion.h"
#include <wx/wx.h>
#include <wx/grid.h>

class kurslaus : public wxDialog {
public:
  kurslaus(wxWindow *parent, const LEntry& entry, const LKrit& krit);

private:
  void onButton (wxCommandEvent& e);

  DECLARE_EVENT_TABLE()
};

enum {
  NEXT_B = 1,
  PREV_B
};

#endif
